# generated by datamodel-codegen:
#   filename:  fields.json
#   timestamp: 2025-01-27T15:02:42+00:00

from __future__ import annotations

from typing import List, Optional

from pydantic import AnyUrl, BaseModel, Field


class IsAboutItem(BaseModel):
    name: Optional[str] = Field(
        None,
        description='The class label of the ontology term.',
        examples=['wind energy converting unit'],
        title='Is About Name',
    )
    field_id: Optional[AnyUrl] = Field(
        None,
        alias='@id',
        description='The path of the ontology term (IRI).',
        examples=['https://openenergyplatform.org/ontology/oeo/OEO_00000044'],
        title='Is About Identifier',
    )


class ValueReferenceItem(BaseModel):
    value: Optional[str] = Field(
        None,
        description='The name of the value in the column.',
        examples=['onshore'],
        title='Value',
    )
    name: Optional[str] = Field(
        None,
        description='The class label of the ontology term in the column.',
        examples=['onshore wind farm'],
        title='Value Reference Name',
    )
    field_id: Optional[AnyUrl] = Field(
        None,
        alias='@id',
        description='The path of the ontology term (IRI) in the column.',
        examples=['https://openenergyplatform.org/ontology/oeo/OEO_00000311'],
        title='Value Reference Identifier',
    )


class FieldModel(BaseModel):
    name: Optional[str] = Field(
        ...,
        description='The name of the field. The name may only consist of lowercase alphanumeric characters or underscores. It must not begin with a number or an underscore.',
        examples=['year'],
        title='Column Name',
    )
    description: Optional[str] = Field(
        None,
        description='A text describing the field.',
        examples=['Reference year for which the data was collected.'],
        title='Description',
    )
    type: Optional[str] = Field(
        ...,
        description='The data type of the field. In case of a geom column in a database, '
                    'also indicate the shape and CRS.',
        examples=['geometry(Point, 4326)'],
        title='Type',
    )
    nullable: Optional[bool] = Field(
        ...,
        description='A boolean key to specify that a column can be nullable. True is the default value.',
        examples=[True],
        title='Nullable',
    )
    unit: Optional[str] = Field(
        None,
        description="The unit of a field. If it does not apply, use 'null'. If the unit is given in a separate field, "
                    "reference this field (e.g. 'unit'). Use a space between numbers and units (100 m).",
        examples=['MW'],
        title='Unit',
    )
    isAbout: Optional[List[IsAboutItem]] = Field(
        None,
        description='An array of objects that describes the field in ontology terms.',
        title='isAbout',
    )
    valueReference: Optional[List[ValueReferenceItem]] = Field(
        None,
        description='An array of objects for an extended description of the values in the column in ontology terms.',
        title='valueReference',
    )


class Reference(BaseModel):
    resource: Optional[str] = Field(
        ...,
        description='The referenced foreign table.',
        examples=['model_draft.oep_oemetadata_table_example_version'],
        title='Foreign Resource',
    )
    fields: List[Optional[str]] = Field(
        ..., description='The foreign resource column.', title='Field'
    )


class ForeignKey(BaseModel):
    fields: List[Optional[str]] = Field(
        ...,
        description='An array of fields in the table that is constrained by the foreign key.',
        title='Fields',
    )
    reference: Optional[Reference] = Field(
        None, description='The reference to the foreign table.', title='Reference'
    )


class Schema(BaseModel):
    fields: Optional[List[FieldModel]] = Field(
        None,
        description='An array of objects that describes a field (column) and its detailed information.',
        title='Field',
    )
    primaryKey: List[Optional[str]] = Field(
        ...,
        description='An array of fields that uniquely identifies each row in the table.',
        title='Primary key',
    )
    foreignKeys: Optional[List[ForeignKey]] = Field(
        None, description='List of foreign keys.', title='Foreign Keys'
    )


class Dialect(BaseModel):
    delimiter: Optional[str] = Field(
        None,
        description="The delimiter specifies the character sequence which should separate fields (columns). "
                    "Common characters are ',' (comma), ';' (semicolon), '.' (point) and '\\t' (tab).",
        examples=[';'],
        title='Delimiter',
    )
    decimalSeparator: Optional[str] = Field(
        None,
        description="The symbol used to separate the integer part from the fractional part of a number written in "
                    "decimal form. Depending on language and region this symbol can be '.' or ','.",
        examples=['.'],
        title='Decimal separator',
    )


class Model(BaseModel):
    type: Optional[str] = Field(
        None,
        description="The 'table' type indicates that the resource is tabular "
                    "as per 'Frictionless Tabular Data' definition.",
        examples=['table'],
        title='Type',
    )
    format: Optional[str] = Field(
        None,
        description="A file extension format. Possible options are 'csv', 'xlsx', 'json', 'PostgreSQL', "
                    "'SQLite' and other standard file extensions.",
        examples=['CSV'],
        title='Format',
    )
    encoding: Optional[str] = Field(
        None,
        description="Specifies the character encoding of the resource's data file. The default is 'UTF-8'. "
                    "The values should be one of the 'Preferred MIME Names'.",
        examples=['UTF-8'],
        title='Encoding',
    )
    schema_: Optional[Schema] = Field(
        None,
        alias='schema',
        description='An object that describes the structure of a table. It contains all fields (columns of the table), '
                    'the primary key and optional foreign keys.',
        title='Schema',
    )
    dialect: Optional[Dialect] = Field(
        None,
        description="The Dialect defines a simple format for describing the various dialects of CSV files in"
                    "a language-independent manner. In a database, the values in the fields are 'null'.",
        title='Dialect',
    )
