# install required packages with: pip install "oep-client>=0.17"
# import required packages

import logging
from pathlib import Path
from getpass import getpass
from os import environ
from random import randint

from oep_client import OepClient
from excel_sheet_adapter import ExcelSheetAdapter

# set default value for the oep token
environ.setdefault('OEP_API_TOKEN',
                   "f00fa56fa4554da3714832a9452525248f9c4988")

topic = "sandbox"
table = f"living_lab_table_{randint(0, 100000)}"

# configure logger. Please select your logging level
# INFO or DEBUG. Logs are to find under log/
logging.basicConfig(level=logging.DEBUG,
                    filename='log/'+table+'.log',
                    format="[%(asctime)s %(module)16s %(levelname)7s] %(message)s",
                    filemode='w')
logger = logging.getLogger(__name__)
logger.info('Starting LLEC upload')

path_to_source = ('/Users/ot2661/Documents/01_dev/aed_pub/regimo/regimo/services/backend_regimo/data' +
                  '/LLEC_Data/dataset_sample_2rows.xlsx')
url_to_source = "https://github.com/koubaa-hmc/LLEC_Data/raw/refs/heads/main/dataset_sample_2rows.xlsx"

token = environ.get("OEP_API_TOKEN") or getpass("Enter your OEP API token: ")

# for read/write, we need to add authorization header
auth_headers = {"Authorization": "Token %s" % token}
table_api_url = f"https://openenergyplatform.org/api/v0/schema/{topic}/tables/{table}/"
logger.info("Table API URL: %s" % table_api_url)

# instantiate table source
table_source = ExcelSheetAdapter(table_path=Path(path_to_source),
                                 data_sheet_name='dataset_sample_2rows_comp',
                                 metadata_sheet_name='dataset_sample_2rows_meta')
# get header
table_schema_definition = table_source.get_header()

# load data
table_data = table_source.get_data()
table_metadata = table_source.get_metadata()
# todo: handle metadata with in an object(oemeta)

# instantiate client to oep
cli = OepClient(token=token, default_schema=topic)
cli.create_table(table, table_schema_definition)
cli.insert_into_table(table, table_data)

# get metadata (from example file)
# metadata = req.get(
#    "https://raw.githubusercontent.com/OpenEnergyPlatform/academy/production/docs/data/tutorial_example_table.metadata.json").json()

# metadata = cli.set_metadata(table, metadata)
# print(json.dumps(metadata, indent=4))
